// ABBYY® Mobile Capture © 2019 ABBYY Production LLC.
// ABBYY is a registered trademark or a trademark of ABBYY Software Ltd.

#import "ImageLoader.h"

@interface ImageLoader ()

@property (nonatomic, strong) NSMutableDictionary* operations;
@property (nonatomic, strong) NSOperationQueue* loadingQueue;

@end

@interface ImageLoadOperation : NSOperation

@property (nonatomic, strong) NSString* path;
@property (nonatomic, copy) ImageLoadingCompletion completion;
@property (nonatomic, weak) ImageLoader* parent;

@end

@implementation ImageLoadOperation

- (void)main
{
	if(self.isCancelled) {
		return;
	}
	
	UIImage* image = [UIImage imageWithContentsOfFile:self.path];
	
	if(self.isCancelled) {
		return;
	}
	dispatch_async(dispatch_get_main_queue(), ^{
		self.completion(image);
		self.parent.operations[self.path] = nil;
	});
}

@end

@implementation ImageLoader

- (NSMutableDictionary*)operations
{
	if(_operations == nil) {
		_operations = [NSMutableDictionary dictionary];
	}
	return _operations;
}

- (NSOperationQueue*)loadingQueue
{
	if(_loadingQueue == nil) {
		_loadingQueue = [NSOperationQueue new];
	}
	return _loadingQueue;
}

- (void)loadImageWith:(NSString*)path completion:(ImageLoadingCompletion)completion
{
	ImageLoadOperation* operation = self.operations[path];
	if(operation == nil) {
		operation = [ImageLoadOperation new];
		operation.path = path;
		operation.parent = self;
		self.operations[path] = operation;
		[self.loadingQueue addOperation:operation];
	}
	operation.completion = completion;
}

- (void)cancelLoading:(NSString*)path
{
	if(path.length > 0) {
		ImageLoadOperation* operation = self.operations[path];
		if(operation != nil) {
			self.operations[path] = nil;
			[operation cancel];
		}
	}
}

- (void)clear
{
	[self.loadingQueue cancelAllOperations];
	self.operations = nil;
}

@end
